/*
Turbot Pipes

Turbot Pipes is an intelligence, automation & security platform built specifically for DevOps.

API version: {{OPEN_API_VERSION}}
*/

// Code generated by OpenAPI Generator (https://openapi-generator.tech); DO NOT EDIT.

package pipes

import (
	"encoding/json"
)

// Connection struct for Connection
type Connection struct {
	// The plugin or connection configuration.
	Config *map[string]interface{} `json:"config,omitempty"`
	// The source of the configuration that the conection will use. One of `self` or `integration`.
	ConfigSource *ConnectionConfigSource `json:"config_source,omitempty"`
	// The time of creation in ISO 8601 UTC.
	CreatedAt string `json:"created_at"`
	// User information for the user who created this.
	CreatedBy *User `json:"created_by,omitempty"`
	// The ID of the user that created this.
	CreatedById string `json:"created_by_id"`
	// The source of the credential that the conection will use. One of `self` or `integration`.
	CredentialSource *ConnectionCredentialSource `json:"credential_source,omitempty"`
	// The time the item was deleted in ISO 8601 UTC.
	DeletedAt *string `json:"deleted_at,omitempty"`
	// User information for the user that performed the deletion.
	DeletedBy *User `json:"deleted_by,omitempty"`
	// The ID of the user that performed the deletion.
	DeletedById string `json:"deleted_by_id"`
	// The handle name of the  connection.
	Handle *string `json:"handle,omitempty"`
	// The dynamically-generated handle for the connection. Only populated if this is a discovered connection.
	HandleDynamic *string `json:"handle_dynamic,omitempty"`
	// The handle mode for the connection.
	HandleMode *ConnectionHandleMode `json:"handle_mode,omitempty"`
	// The unique identifier for the connection.
	Id string `json:"id"`
	// The unique identifier for an identity where the connection has been created.
	IdentityId *string `json:"identity_id,omitempty"`
	// Details of the integration that manages this connection.
	Integration *Integration `json:"integration,omitempty"`
	// The source identifier for this connection. Only populated if its a connection thats been discovered by an integration.
	IntegrationResourceIdentifier *string `json:"integration_resource_identifier,omitempty"`
	// A friendly resource name for the connection. Only populated if its a connection thats been doscovered by an integration.
	IntegrationResourceName *string `json:"integration_resource_name,omitempty"`
	// The source path for this connection. Only populated if its a connection thats been discovered by an integration.
	IntegrationResourcePath *string `json:"integration_resource_path,omitempty"`
	// The source type for this connection. Only populated if its a connection thats been discovered by an integration.
	IntegrationResourceType *string `json:"integration_resource_type,omitempty"`
	// The ID of the aggregator that manages this connection. Only populated if this is a discovered connection.
	ManagedById *string `json:"managed_by_id,omitempty"`
	// The id of the entity where the connection is stored. Can be either tenant, identity, workspace or connection-folder.
	ParentId string `json:"parent_id"`
	// The plugin name for the connection.
	Plugin *string `json:"plugin,omitempty"`
	// The plugin version for the connection.
	PluginVersion *string `json:"plugin_version,omitempty"`
	// The unique identifier for the tenant where the connection has been created.
	TenantId string `json:"tenant_id"`
	// The title of the connection. Only populated when the connection is of type connection folder.
	Title *string `json:"title,omitempty"`
	// The trunk for the connection.
	Trunk *[]ConnectionTrunkItem `json:"trunk,omitempty"`
	// Type of connection i.e aggregator or connection.
	Type *string `json:"type,omitempty"`
	// The time of the last update in ISO 8601 UTC.
	UpdatedAt *string `json:"updated_at,omitempty"`
	// User information for the last user to update this.
	UpdatedBy *User `json:"updated_by,omitempty"`
	// The ID of the user that performed the last update.
	UpdatedById string `json:"updated_by_id"`
	// The version ID of this item. Pass this version ID via an If-Match header when performing mutation operations on the item.
	VersionId int32 `json:"version_id"`
	// The unique identifier for the workspace where the connection has been created.
	WorkspaceId *string `json:"workspace_id,omitempty"`
}

// NewConnection instantiates a new Connection object
// This constructor will assign default values to properties that have it defined,
// and makes sure properties required by API are set, but the set of arguments
// will change when the set of required properties is changed
func NewConnection(createdAt string, createdById string, deletedById string, id string, parentId string, tenantId string, updatedById string, versionId int32) *Connection {
	this := Connection{}
	this.CreatedAt = createdAt
	this.CreatedById = createdById
	this.DeletedById = deletedById
	this.Id = id
	this.ParentId = parentId
	this.TenantId = tenantId
	this.UpdatedById = updatedById
	this.VersionId = versionId
	return &this
}

// NewConnectionWithDefaults instantiates a new Connection object
// This constructor will only assign default values to properties that have it defined,
// but it doesn't guarantee that properties required by API are set
func NewConnectionWithDefaults() *Connection {
	this := Connection{}
	return &this
}

// GetConfig returns the Config field value if set, zero value otherwise.
func (o *Connection) GetConfig() map[string]interface{} {
	if o == nil || o.Config == nil {
		var ret map[string]interface{}
		return ret
	}
	return *o.Config
}

// GetConfigOk returns a tuple with the Config field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetConfigOk() (*map[string]interface{}, bool) {
	if o == nil || o.Config == nil {
		return nil, false
	}
	return o.Config, true
}

// HasConfig returns a boolean if a field has been set.
func (o *Connection) HasConfig() bool {
	if o != nil && o.Config != nil {
		return true
	}

	return false
}

// SetConfig gets a reference to the given map[string]interface{} and assigns it to the Config field.
func (o *Connection) SetConfig(v map[string]interface{}) {
	o.Config = &v
}

// GetConfigSource returns the ConfigSource field value if set, zero value otherwise.
func (o *Connection) GetConfigSource() ConnectionConfigSource {
	if o == nil || o.ConfigSource == nil {
		var ret ConnectionConfigSource
		return ret
	}
	return *o.ConfigSource
}

// GetConfigSourceOk returns a tuple with the ConfigSource field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetConfigSourceOk() (*ConnectionConfigSource, bool) {
	if o == nil || o.ConfigSource == nil {
		return nil, false
	}
	return o.ConfigSource, true
}

// HasConfigSource returns a boolean if a field has been set.
func (o *Connection) HasConfigSource() bool {
	if o != nil && o.ConfigSource != nil {
		return true
	}

	return false
}

// SetConfigSource gets a reference to the given ConnectionConfigSource and assigns it to the ConfigSource field.
func (o *Connection) SetConfigSource(v ConnectionConfigSource) {
	o.ConfigSource = &v
}

// GetCreatedAt returns the CreatedAt field value
func (o *Connection) GetCreatedAt() string {
	if o == nil {
		var ret string
		return ret
	}

	return o.CreatedAt
}

// GetCreatedAtOk returns a tuple with the CreatedAt field value
// and a boolean to check if the value has been set.
func (o *Connection) GetCreatedAtOk() (*string, bool) {
	if o == nil {
		return nil, false
	}
	return &o.CreatedAt, true
}

// SetCreatedAt sets field value
func (o *Connection) SetCreatedAt(v string) {
	o.CreatedAt = v
}

// GetCreatedBy returns the CreatedBy field value if set, zero value otherwise.
func (o *Connection) GetCreatedBy() User {
	if o == nil || o.CreatedBy == nil {
		var ret User
		return ret
	}
	return *o.CreatedBy
}

// GetCreatedByOk returns a tuple with the CreatedBy field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetCreatedByOk() (*User, bool) {
	if o == nil || o.CreatedBy == nil {
		return nil, false
	}
	return o.CreatedBy, true
}

// HasCreatedBy returns a boolean if a field has been set.
func (o *Connection) HasCreatedBy() bool {
	if o != nil && o.CreatedBy != nil {
		return true
	}

	return false
}

// SetCreatedBy gets a reference to the given User and assigns it to the CreatedBy field.
func (o *Connection) SetCreatedBy(v User) {
	o.CreatedBy = &v
}

// GetCreatedById returns the CreatedById field value
func (o *Connection) GetCreatedById() string {
	if o == nil {
		var ret string
		return ret
	}

	return o.CreatedById
}

// GetCreatedByIdOk returns a tuple with the CreatedById field value
// and a boolean to check if the value has been set.
func (o *Connection) GetCreatedByIdOk() (*string, bool) {
	if o == nil {
		return nil, false
	}
	return &o.CreatedById, true
}

// SetCreatedById sets field value
func (o *Connection) SetCreatedById(v string) {
	o.CreatedById = v
}

// GetCredentialSource returns the CredentialSource field value if set, zero value otherwise.
func (o *Connection) GetCredentialSource() ConnectionCredentialSource {
	if o == nil || o.CredentialSource == nil {
		var ret ConnectionCredentialSource
		return ret
	}
	return *o.CredentialSource
}

// GetCredentialSourceOk returns a tuple with the CredentialSource field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetCredentialSourceOk() (*ConnectionCredentialSource, bool) {
	if o == nil || o.CredentialSource == nil {
		return nil, false
	}
	return o.CredentialSource, true
}

// HasCredentialSource returns a boolean if a field has been set.
func (o *Connection) HasCredentialSource() bool {
	if o != nil && o.CredentialSource != nil {
		return true
	}

	return false
}

// SetCredentialSource gets a reference to the given ConnectionCredentialSource and assigns it to the CredentialSource field.
func (o *Connection) SetCredentialSource(v ConnectionCredentialSource) {
	o.CredentialSource = &v
}

// GetDeletedAt returns the DeletedAt field value if set, zero value otherwise.
func (o *Connection) GetDeletedAt() string {
	if o == nil || o.DeletedAt == nil {
		var ret string
		return ret
	}
	return *o.DeletedAt
}

// GetDeletedAtOk returns a tuple with the DeletedAt field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetDeletedAtOk() (*string, bool) {
	if o == nil || o.DeletedAt == nil {
		return nil, false
	}
	return o.DeletedAt, true
}

// HasDeletedAt returns a boolean if a field has been set.
func (o *Connection) HasDeletedAt() bool {
	if o != nil && o.DeletedAt != nil {
		return true
	}

	return false
}

// SetDeletedAt gets a reference to the given string and assigns it to the DeletedAt field.
func (o *Connection) SetDeletedAt(v string) {
	o.DeletedAt = &v
}

// GetDeletedBy returns the DeletedBy field value if set, zero value otherwise.
func (o *Connection) GetDeletedBy() User {
	if o == nil || o.DeletedBy == nil {
		var ret User
		return ret
	}
	return *o.DeletedBy
}

// GetDeletedByOk returns a tuple with the DeletedBy field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetDeletedByOk() (*User, bool) {
	if o == nil || o.DeletedBy == nil {
		return nil, false
	}
	return o.DeletedBy, true
}

// HasDeletedBy returns a boolean if a field has been set.
func (o *Connection) HasDeletedBy() bool {
	if o != nil && o.DeletedBy != nil {
		return true
	}

	return false
}

// SetDeletedBy gets a reference to the given User and assigns it to the DeletedBy field.
func (o *Connection) SetDeletedBy(v User) {
	o.DeletedBy = &v
}

// GetDeletedById returns the DeletedById field value
func (o *Connection) GetDeletedById() string {
	if o == nil {
		var ret string
		return ret
	}

	return o.DeletedById
}

// GetDeletedByIdOk returns a tuple with the DeletedById field value
// and a boolean to check if the value has been set.
func (o *Connection) GetDeletedByIdOk() (*string, bool) {
	if o == nil {
		return nil, false
	}
	return &o.DeletedById, true
}

// SetDeletedById sets field value
func (o *Connection) SetDeletedById(v string) {
	o.DeletedById = v
}

// GetHandle returns the Handle field value if set, zero value otherwise.
func (o *Connection) GetHandle() string {
	if o == nil || o.Handle == nil {
		var ret string
		return ret
	}
	return *o.Handle
}

// GetHandleOk returns a tuple with the Handle field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetHandleOk() (*string, bool) {
	if o == nil || o.Handle == nil {
		return nil, false
	}
	return o.Handle, true
}

// HasHandle returns a boolean if a field has been set.
func (o *Connection) HasHandle() bool {
	if o != nil && o.Handle != nil {
		return true
	}

	return false
}

// SetHandle gets a reference to the given string and assigns it to the Handle field.
func (o *Connection) SetHandle(v string) {
	o.Handle = &v
}

// GetHandleDynamic returns the HandleDynamic field value if set, zero value otherwise.
func (o *Connection) GetHandleDynamic() string {
	if o == nil || o.HandleDynamic == nil {
		var ret string
		return ret
	}
	return *o.HandleDynamic
}

// GetHandleDynamicOk returns a tuple with the HandleDynamic field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetHandleDynamicOk() (*string, bool) {
	if o == nil || o.HandleDynamic == nil {
		return nil, false
	}
	return o.HandleDynamic, true
}

// HasHandleDynamic returns a boolean if a field has been set.
func (o *Connection) HasHandleDynamic() bool {
	if o != nil && o.HandleDynamic != nil {
		return true
	}

	return false
}

// SetHandleDynamic gets a reference to the given string and assigns it to the HandleDynamic field.
func (o *Connection) SetHandleDynamic(v string) {
	o.HandleDynamic = &v
}

// GetHandleMode returns the HandleMode field value if set, zero value otherwise.
func (o *Connection) GetHandleMode() ConnectionHandleMode {
	if o == nil || o.HandleMode == nil {
		var ret ConnectionHandleMode
		return ret
	}
	return *o.HandleMode
}

// GetHandleModeOk returns a tuple with the HandleMode field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetHandleModeOk() (*ConnectionHandleMode, bool) {
	if o == nil || o.HandleMode == nil {
		return nil, false
	}
	return o.HandleMode, true
}

// HasHandleMode returns a boolean if a field has been set.
func (o *Connection) HasHandleMode() bool {
	if o != nil && o.HandleMode != nil {
		return true
	}

	return false
}

// SetHandleMode gets a reference to the given ConnectionHandleMode and assigns it to the HandleMode field.
func (o *Connection) SetHandleMode(v ConnectionHandleMode) {
	o.HandleMode = &v
}

// GetId returns the Id field value
func (o *Connection) GetId() string {
	if o == nil {
		var ret string
		return ret
	}

	return o.Id
}

// GetIdOk returns a tuple with the Id field value
// and a boolean to check if the value has been set.
func (o *Connection) GetIdOk() (*string, bool) {
	if o == nil {
		return nil, false
	}
	return &o.Id, true
}

// SetId sets field value
func (o *Connection) SetId(v string) {
	o.Id = v
}

// GetIdentityId returns the IdentityId field value if set, zero value otherwise.
func (o *Connection) GetIdentityId() string {
	if o == nil || o.IdentityId == nil {
		var ret string
		return ret
	}
	return *o.IdentityId
}

// GetIdentityIdOk returns a tuple with the IdentityId field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetIdentityIdOk() (*string, bool) {
	if o == nil || o.IdentityId == nil {
		return nil, false
	}
	return o.IdentityId, true
}

// HasIdentityId returns a boolean if a field has been set.
func (o *Connection) HasIdentityId() bool {
	if o != nil && o.IdentityId != nil {
		return true
	}

	return false
}

// SetIdentityId gets a reference to the given string and assigns it to the IdentityId field.
func (o *Connection) SetIdentityId(v string) {
	o.IdentityId = &v
}

// GetIntegration returns the Integration field value if set, zero value otherwise.
func (o *Connection) GetIntegration() Integration {
	if o == nil || o.Integration == nil {
		var ret Integration
		return ret
	}
	return *o.Integration
}

// GetIntegrationOk returns a tuple with the Integration field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetIntegrationOk() (*Integration, bool) {
	if o == nil || o.Integration == nil {
		return nil, false
	}
	return o.Integration, true
}

// HasIntegration returns a boolean if a field has been set.
func (o *Connection) HasIntegration() bool {
	if o != nil && o.Integration != nil {
		return true
	}

	return false
}

// SetIntegration gets a reference to the given Integration and assigns it to the Integration field.
func (o *Connection) SetIntegration(v Integration) {
	o.Integration = &v
}

// GetIntegrationResourceIdentifier returns the IntegrationResourceIdentifier field value if set, zero value otherwise.
func (o *Connection) GetIntegrationResourceIdentifier() string {
	if o == nil || o.IntegrationResourceIdentifier == nil {
		var ret string
		return ret
	}
	return *o.IntegrationResourceIdentifier
}

// GetIntegrationResourceIdentifierOk returns a tuple with the IntegrationResourceIdentifier field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetIntegrationResourceIdentifierOk() (*string, bool) {
	if o == nil || o.IntegrationResourceIdentifier == nil {
		return nil, false
	}
	return o.IntegrationResourceIdentifier, true
}

// HasIntegrationResourceIdentifier returns a boolean if a field has been set.
func (o *Connection) HasIntegrationResourceIdentifier() bool {
	if o != nil && o.IntegrationResourceIdentifier != nil {
		return true
	}

	return false
}

// SetIntegrationResourceIdentifier gets a reference to the given string and assigns it to the IntegrationResourceIdentifier field.
func (o *Connection) SetIntegrationResourceIdentifier(v string) {
	o.IntegrationResourceIdentifier = &v
}

// GetIntegrationResourceName returns the IntegrationResourceName field value if set, zero value otherwise.
func (o *Connection) GetIntegrationResourceName() string {
	if o == nil || o.IntegrationResourceName == nil {
		var ret string
		return ret
	}
	return *o.IntegrationResourceName
}

// GetIntegrationResourceNameOk returns a tuple with the IntegrationResourceName field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetIntegrationResourceNameOk() (*string, bool) {
	if o == nil || o.IntegrationResourceName == nil {
		return nil, false
	}
	return o.IntegrationResourceName, true
}

// HasIntegrationResourceName returns a boolean if a field has been set.
func (o *Connection) HasIntegrationResourceName() bool {
	if o != nil && o.IntegrationResourceName != nil {
		return true
	}

	return false
}

// SetIntegrationResourceName gets a reference to the given string and assigns it to the IntegrationResourceName field.
func (o *Connection) SetIntegrationResourceName(v string) {
	o.IntegrationResourceName = &v
}

// GetIntegrationResourcePath returns the IntegrationResourcePath field value if set, zero value otherwise.
func (o *Connection) GetIntegrationResourcePath() string {
	if o == nil || o.IntegrationResourcePath == nil {
		var ret string
		return ret
	}
	return *o.IntegrationResourcePath
}

// GetIntegrationResourcePathOk returns a tuple with the IntegrationResourcePath field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetIntegrationResourcePathOk() (*string, bool) {
	if o == nil || o.IntegrationResourcePath == nil {
		return nil, false
	}
	return o.IntegrationResourcePath, true
}

// HasIntegrationResourcePath returns a boolean if a field has been set.
func (o *Connection) HasIntegrationResourcePath() bool {
	if o != nil && o.IntegrationResourcePath != nil {
		return true
	}

	return false
}

// SetIntegrationResourcePath gets a reference to the given string and assigns it to the IntegrationResourcePath field.
func (o *Connection) SetIntegrationResourcePath(v string) {
	o.IntegrationResourcePath = &v
}

// GetIntegrationResourceType returns the IntegrationResourceType field value if set, zero value otherwise.
func (o *Connection) GetIntegrationResourceType() string {
	if o == nil || o.IntegrationResourceType == nil {
		var ret string
		return ret
	}
	return *o.IntegrationResourceType
}

// GetIntegrationResourceTypeOk returns a tuple with the IntegrationResourceType field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetIntegrationResourceTypeOk() (*string, bool) {
	if o == nil || o.IntegrationResourceType == nil {
		return nil, false
	}
	return o.IntegrationResourceType, true
}

// HasIntegrationResourceType returns a boolean if a field has been set.
func (o *Connection) HasIntegrationResourceType() bool {
	if o != nil && o.IntegrationResourceType != nil {
		return true
	}

	return false
}

// SetIntegrationResourceType gets a reference to the given string and assigns it to the IntegrationResourceType field.
func (o *Connection) SetIntegrationResourceType(v string) {
	o.IntegrationResourceType = &v
}

// GetManagedById returns the ManagedById field value if set, zero value otherwise.
func (o *Connection) GetManagedById() string {
	if o == nil || o.ManagedById == nil {
		var ret string
		return ret
	}
	return *o.ManagedById
}

// GetManagedByIdOk returns a tuple with the ManagedById field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetManagedByIdOk() (*string, bool) {
	if o == nil || o.ManagedById == nil {
		return nil, false
	}
	return o.ManagedById, true
}

// HasManagedById returns a boolean if a field has been set.
func (o *Connection) HasManagedById() bool {
	if o != nil && o.ManagedById != nil {
		return true
	}

	return false
}

// SetManagedById gets a reference to the given string and assigns it to the ManagedById field.
func (o *Connection) SetManagedById(v string) {
	o.ManagedById = &v
}

// GetParentId returns the ParentId field value
func (o *Connection) GetParentId() string {
	if o == nil {
		var ret string
		return ret
	}

	return o.ParentId
}

// GetParentIdOk returns a tuple with the ParentId field value
// and a boolean to check if the value has been set.
func (o *Connection) GetParentIdOk() (*string, bool) {
	if o == nil {
		return nil, false
	}
	return &o.ParentId, true
}

// SetParentId sets field value
func (o *Connection) SetParentId(v string) {
	o.ParentId = v
}

// GetPlugin returns the Plugin field value if set, zero value otherwise.
func (o *Connection) GetPlugin() string {
	if o == nil || o.Plugin == nil {
		var ret string
		return ret
	}
	return *o.Plugin
}

// GetPluginOk returns a tuple with the Plugin field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetPluginOk() (*string, bool) {
	if o == nil || o.Plugin == nil {
		return nil, false
	}
	return o.Plugin, true
}

// HasPlugin returns a boolean if a field has been set.
func (o *Connection) HasPlugin() bool {
	if o != nil && o.Plugin != nil {
		return true
	}

	return false
}

// SetPlugin gets a reference to the given string and assigns it to the Plugin field.
func (o *Connection) SetPlugin(v string) {
	o.Plugin = &v
}

// GetPluginVersion returns the PluginVersion field value if set, zero value otherwise.
func (o *Connection) GetPluginVersion() string {
	if o == nil || o.PluginVersion == nil {
		var ret string
		return ret
	}
	return *o.PluginVersion
}

// GetPluginVersionOk returns a tuple with the PluginVersion field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetPluginVersionOk() (*string, bool) {
	if o == nil || o.PluginVersion == nil {
		return nil, false
	}
	return o.PluginVersion, true
}

// HasPluginVersion returns a boolean if a field has been set.
func (o *Connection) HasPluginVersion() bool {
	if o != nil && o.PluginVersion != nil {
		return true
	}

	return false
}

// SetPluginVersion gets a reference to the given string and assigns it to the PluginVersion field.
func (o *Connection) SetPluginVersion(v string) {
	o.PluginVersion = &v
}

// GetTenantId returns the TenantId field value
func (o *Connection) GetTenantId() string {
	if o == nil {
		var ret string
		return ret
	}

	return o.TenantId
}

// GetTenantIdOk returns a tuple with the TenantId field value
// and a boolean to check if the value has been set.
func (o *Connection) GetTenantIdOk() (*string, bool) {
	if o == nil {
		return nil, false
	}
	return &o.TenantId, true
}

// SetTenantId sets field value
func (o *Connection) SetTenantId(v string) {
	o.TenantId = v
}

// GetTitle returns the Title field value if set, zero value otherwise.
func (o *Connection) GetTitle() string {
	if o == nil || o.Title == nil {
		var ret string
		return ret
	}
	return *o.Title
}

// GetTitleOk returns a tuple with the Title field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetTitleOk() (*string, bool) {
	if o == nil || o.Title == nil {
		return nil, false
	}
	return o.Title, true
}

// HasTitle returns a boolean if a field has been set.
func (o *Connection) HasTitle() bool {
	if o != nil && o.Title != nil {
		return true
	}

	return false
}

// SetTitle gets a reference to the given string and assigns it to the Title field.
func (o *Connection) SetTitle(v string) {
	o.Title = &v
}

// GetTrunk returns the Trunk field value if set, zero value otherwise.
func (o *Connection) GetTrunk() []ConnectionTrunkItem {
	if o == nil || o.Trunk == nil {
		var ret []ConnectionTrunkItem
		return ret
	}
	return *o.Trunk
}

// GetTrunkOk returns a tuple with the Trunk field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetTrunkOk() (*[]ConnectionTrunkItem, bool) {
	if o == nil || o.Trunk == nil {
		return nil, false
	}
	return o.Trunk, true
}

// HasTrunk returns a boolean if a field has been set.
func (o *Connection) HasTrunk() bool {
	if o != nil && o.Trunk != nil {
		return true
	}

	return false
}

// SetTrunk gets a reference to the given []ConnectionTrunkItem and assigns it to the Trunk field.
func (o *Connection) SetTrunk(v []ConnectionTrunkItem) {
	o.Trunk = &v
}

// GetType returns the Type field value if set, zero value otherwise.
func (o *Connection) GetType() string {
	if o == nil || o.Type == nil {
		var ret string
		return ret
	}
	return *o.Type
}

// GetTypeOk returns a tuple with the Type field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetTypeOk() (*string, bool) {
	if o == nil || o.Type == nil {
		return nil, false
	}
	return o.Type, true
}

// HasType returns a boolean if a field has been set.
func (o *Connection) HasType() bool {
	if o != nil && o.Type != nil {
		return true
	}

	return false
}

// SetType gets a reference to the given string and assigns it to the Type field.
func (o *Connection) SetType(v string) {
	o.Type = &v
}

// GetUpdatedAt returns the UpdatedAt field value if set, zero value otherwise.
func (o *Connection) GetUpdatedAt() string {
	if o == nil || o.UpdatedAt == nil {
		var ret string
		return ret
	}
	return *o.UpdatedAt
}

// GetUpdatedAtOk returns a tuple with the UpdatedAt field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetUpdatedAtOk() (*string, bool) {
	if o == nil || o.UpdatedAt == nil {
		return nil, false
	}
	return o.UpdatedAt, true
}

// HasUpdatedAt returns a boolean if a field has been set.
func (o *Connection) HasUpdatedAt() bool {
	if o != nil && o.UpdatedAt != nil {
		return true
	}

	return false
}

// SetUpdatedAt gets a reference to the given string and assigns it to the UpdatedAt field.
func (o *Connection) SetUpdatedAt(v string) {
	o.UpdatedAt = &v
}

// GetUpdatedBy returns the UpdatedBy field value if set, zero value otherwise.
func (o *Connection) GetUpdatedBy() User {
	if o == nil || o.UpdatedBy == nil {
		var ret User
		return ret
	}
	return *o.UpdatedBy
}

// GetUpdatedByOk returns a tuple with the UpdatedBy field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetUpdatedByOk() (*User, bool) {
	if o == nil || o.UpdatedBy == nil {
		return nil, false
	}
	return o.UpdatedBy, true
}

// HasUpdatedBy returns a boolean if a field has been set.
func (o *Connection) HasUpdatedBy() bool {
	if o != nil && o.UpdatedBy != nil {
		return true
	}

	return false
}

// SetUpdatedBy gets a reference to the given User and assigns it to the UpdatedBy field.
func (o *Connection) SetUpdatedBy(v User) {
	o.UpdatedBy = &v
}

// GetUpdatedById returns the UpdatedById field value
func (o *Connection) GetUpdatedById() string {
	if o == nil {
		var ret string
		return ret
	}

	return o.UpdatedById
}

// GetUpdatedByIdOk returns a tuple with the UpdatedById field value
// and a boolean to check if the value has been set.
func (o *Connection) GetUpdatedByIdOk() (*string, bool) {
	if o == nil {
		return nil, false
	}
	return &o.UpdatedById, true
}

// SetUpdatedById sets field value
func (o *Connection) SetUpdatedById(v string) {
	o.UpdatedById = v
}

// GetVersionId returns the VersionId field value
func (o *Connection) GetVersionId() int32 {
	if o == nil {
		var ret int32
		return ret
	}

	return o.VersionId
}

// GetVersionIdOk returns a tuple with the VersionId field value
// and a boolean to check if the value has been set.
func (o *Connection) GetVersionIdOk() (*int32, bool) {
	if o == nil {
		return nil, false
	}
	return &o.VersionId, true
}

// SetVersionId sets field value
func (o *Connection) SetVersionId(v int32) {
	o.VersionId = v
}

// GetWorkspaceId returns the WorkspaceId field value if set, zero value otherwise.
func (o *Connection) GetWorkspaceId() string {
	if o == nil || o.WorkspaceId == nil {
		var ret string
		return ret
	}
	return *o.WorkspaceId
}

// GetWorkspaceIdOk returns a tuple with the WorkspaceId field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Connection) GetWorkspaceIdOk() (*string, bool) {
	if o == nil || o.WorkspaceId == nil {
		return nil, false
	}
	return o.WorkspaceId, true
}

// HasWorkspaceId returns a boolean if a field has been set.
func (o *Connection) HasWorkspaceId() bool {
	if o != nil && o.WorkspaceId != nil {
		return true
	}

	return false
}

// SetWorkspaceId gets a reference to the given string and assigns it to the WorkspaceId field.
func (o *Connection) SetWorkspaceId(v string) {
	o.WorkspaceId = &v
}

func (o Connection) MarshalJSON() ([]byte, error) {
	toSerialize := map[string]interface{}{}
	if o.Config != nil {
		toSerialize["config"] = o.Config
	}
	if o.ConfigSource != nil {
		toSerialize["config_source"] = o.ConfigSource
	}
	if true {
		toSerialize["created_at"] = o.CreatedAt
	}
	if o.CreatedBy != nil {
		toSerialize["created_by"] = o.CreatedBy
	}
	if true {
		toSerialize["created_by_id"] = o.CreatedById
	}
	if o.CredentialSource != nil {
		toSerialize["credential_source"] = o.CredentialSource
	}
	if o.DeletedAt != nil {
		toSerialize["deleted_at"] = o.DeletedAt
	}
	if o.DeletedBy != nil {
		toSerialize["deleted_by"] = o.DeletedBy
	}
	if true {
		toSerialize["deleted_by_id"] = o.DeletedById
	}
	if o.Handle != nil {
		toSerialize["handle"] = o.Handle
	}
	if o.HandleDynamic != nil {
		toSerialize["handle_dynamic"] = o.HandleDynamic
	}
	if o.HandleMode != nil {
		toSerialize["handle_mode"] = o.HandleMode
	}
	if true {
		toSerialize["id"] = o.Id
	}
	if o.IdentityId != nil {
		toSerialize["identity_id"] = o.IdentityId
	}
	if o.Integration != nil {
		toSerialize["integration"] = o.Integration
	}
	if o.IntegrationResourceIdentifier != nil {
		toSerialize["integration_resource_identifier"] = o.IntegrationResourceIdentifier
	}
	if o.IntegrationResourceName != nil {
		toSerialize["integration_resource_name"] = o.IntegrationResourceName
	}
	if o.IntegrationResourcePath != nil {
		toSerialize["integration_resource_path"] = o.IntegrationResourcePath
	}
	if o.IntegrationResourceType != nil {
		toSerialize["integration_resource_type"] = o.IntegrationResourceType
	}
	if o.ManagedById != nil {
		toSerialize["managed_by_id"] = o.ManagedById
	}
	if true {
		toSerialize["parent_id"] = o.ParentId
	}
	if o.Plugin != nil {
		toSerialize["plugin"] = o.Plugin
	}
	if o.PluginVersion != nil {
		toSerialize["plugin_version"] = o.PluginVersion
	}
	if true {
		toSerialize["tenant_id"] = o.TenantId
	}
	if o.Title != nil {
		toSerialize["title"] = o.Title
	}
	if o.Trunk != nil {
		toSerialize["trunk"] = o.Trunk
	}
	if o.Type != nil {
		toSerialize["type"] = o.Type
	}
	if o.UpdatedAt != nil {
		toSerialize["updated_at"] = o.UpdatedAt
	}
	if o.UpdatedBy != nil {
		toSerialize["updated_by"] = o.UpdatedBy
	}
	if true {
		toSerialize["updated_by_id"] = o.UpdatedById
	}
	if true {
		toSerialize["version_id"] = o.VersionId
	}
	if o.WorkspaceId != nil {
		toSerialize["workspace_id"] = o.WorkspaceId
	}
	return json.Marshal(toSerialize)
}

type NullableConnection struct {
	value *Connection
	isSet bool
}

func (v NullableConnection) Get() *Connection {
	return v.value
}

func (v *NullableConnection) Set(val *Connection) {
	v.value = val
	v.isSet = true
}

func (v NullableConnection) IsSet() bool {
	return v.isSet
}

func (v *NullableConnection) Unset() {
	v.value = nil
	v.isSet = false
}

func NewNullableConnection(val *Connection) *NullableConnection {
	return &NullableConnection{value: val, isSet: true}
}

func (v NullableConnection) MarshalJSON() ([]byte, error) {
	return json.Marshal(v.value)
}

func (v *NullableConnection) UnmarshalJSON(src []byte) error {
	v.isSet = true
	return json.Unmarshal(src, &v.value)
}
